@@ -2,7 +2,7 @@ import traceback
 from functools import wraps
 from http import HTTPStatus
 from typing import Any
-
+# TODO: use logger_local everywhere with meta loggers & remove logger start/end
 from python_sdk_remote.mini_logger import MiniLogger as logger
 from user_context_remote.user_context import UserContext
 
@@ -13,14 +13,12 @@ AUTHORIZATION_KEY = 'Authorization'
 AUTHORIZATION_PREFIX = 'Bearer '
 
 
-# TODO Align those methods with typescript-sdk https://github.com/circles-zone/typescript-sdk-remote-typescript-package/blob/dev/typescript-sdk/src/utils/index.ts
+# TODO Align those methods with typescript-sdk https://github.com/circles-zone/typescript-sdk-remote-typescript-package/blob/dev/typescript-sdk/src/utils/index.ts  # noqa
 # TODO Shall we create also createInternalServerErrorHttpResponse(), createOkHttpResponse() like we have in TypeScript?
 
-# TODO: add handler wrapper?
-
 def get_payload_dict_from_event(event: dict) -> dict:
     """Extracts params sent with payload"""
-    return to_dict(event.get('body'))
+    return to_dict(event.get('body'))  # TODO all `return statement` should be `return variable`
 
 
 def get_path_parameters_dict_from_event(event: dict) -> dict:
@@ -48,7 +46,7 @@ def get_request_parameters_from_event(event: dict) -> dict:
 
 # TODO: move everything related to serverless to another file
 # TODO: test
-def handler_decorator(logger):
+def handler_decorator(logger, is_validate_user_jwt: bool = True):
     """Decorator for AWS Lambda handler functions. It wraps the handler function with logging and error handling.
     Usage:
     from python_sdk_local.http_response import handler_decorator
@@ -64,11 +62,13 @@ def handler_decorator(logger):
             try:
                 logger.start(object={"event": event, "context": context})
                 request_parameters = get_request_parameters_from_event(event)
-                user_jwt = get_user_jwt_from_event(event)
-                if user_jwt:
-                    request_parameters["user_context"] = UserContext.login_using_user_jwt(user_jwt)
-                else:
-                    logger.warning("No user_jwt provided")
+
+                if is_validate_user_jwt:
+                    user_jwt = get_user_jwt_from_event(event)
+                    if user_jwt:
+                        request_parameters["user_context"] = UserContext.login_using_user_jwt(user_jwt)
+                    else:
+                        logger.warning("No user_jwt provided")
                 body_result = handler(request_parameters)
                 handler_response = create_ok_http_response(body_result)
             except Exception as e:
@@ -118,8 +118,8 @@ def create_error_http_response(exception: Exception, status_code: HTTPStatus = H
     error_http_response = {
         "statusCode": status_code.value,
         "headers": create_return_http_headers(),
-        "body": create_http_body({"error": str(exception)}),
-        "traceback": traceback.format_exc()
+        "body": create_http_body({"error": str(exception),
+                                  "traceback": traceback.format_exc()}),
     }
     logger.end(object={"error_http_response": error_http_response})
     return error_http_response
@@ -128,7 +128,8 @@ def create_error_http_response(exception: Exception, status_code: HTTPStatus = H
 def create_ok_http_response(body: Any) -> dict:
     logger.start(object={"body": body})
     # TODO: test sending statusCode/headers/body inside the body
-
+    if isinstance(body, str) and body.startswith("{") and body.endswith("}"):
+        body = to_dict(body)
     if isinstance(body, dict):
         status_code = body.get("statusCode")
         headers = body.get("headers")
